@@ -61,6 +61,28 @@ class ResultsCollectorJSONCallback(CallbackBase):
         self.host_failed[host.get_name()] = result
 
 
+def random_host(host_list: list,
+                num_target: int):
+
+    new_host_list = host_list[:]
+
+    if num_target <= 0 or num_target > len(new_host_list):
+        raise InvalidActivity('Number of target is not correct')
+
+    try:
+        nb_remove_target = len(new_host_list) - int(num_target)
+
+        if nb_remove_target > 0:
+            for i in range(nb_remove_target):
+                rand = randint(0, len(new_host_list)-1)
+                new_host_list.pop(rand)
+
+    except Exception:
+        raise InvalidActivity('Could not generate host list')
+
+    return new_host_list
+
+
 def chaosansible_run(host_list: list = ('localhost'),
                      configuration: Configuration = None,
                      facts: bool = False,
@@ -100,24 +122,15 @@ def chaosansible_run(host_list: list = ('localhost'),
                                     check=False,
                                     diff=False,
                                     private_key_file=ssh_key_path,
-                                    remote_user=ansible_user,
-                                    become_ask_pass=become_ask_pass)
+                                    remote_user=ansible_user)
 
     # Update host_list regarding the number of desired target.
     # Need to generate a new host-list because after being update
     # and will be used later
-    new_host_list = host_list[:]
     if num_target != 'all':
-        try:
-            nb_remove_target = len(new_host_list) - int(num_target)
-
-            if nb_remove_target > 0:
-                for i in range(nb_remove_target):
-                    rand = randint(0, len(new_host_list)-1)
-                    new_host_list.pop(rand)
-
-        except Exception:
-            raise InvalidActivity('Could not generate host list')
+        new_host_list = random_host(host_list, int(num_target))
+    else:
+        new_host_list = host_list[:]
 
     # Create an inventory
     sources = ','.join(new_host_list)
@@ -131,7 +144,10 @@ def chaosansible_run(host_list: list = ('localhost'),
     results_callback = ResultsCollectorJSONCallback()
 
     variable_manager = VariableManager(loader=loader, inventory=inventory)
-    passwords = dict(vault_pass='secret')
+    if become_ask_pass:
+        passwords = dict(become_pass=become_ask_pass)
+    else:
+        passwords = None
 
     # Ansible taskmanager
     tqm = TaskQueueManager(
@@ -181,10 +197,17 @@ def chaosansible_run(host_list: list = ('localhost'),
     shutil.rmtree(C.DEFAULT_LOCAL_TMP, True)
 
     if len(results_callback.host_failed) > 0:
+        print("Ansible error(s): ")
+        for error in results_callback.host_failed:
+            print(results_callback.host_failed[error].__dict__)
+
         raise FailedActivity("Failed to run ansible task")
 
     elif len(results_callback.host_unreachable) > 0:
-        print("Unreach")
+        print("Unreachable host(s): ")
+        for error in results_callback.host_unreachable:
+            print(error)
+
         raise FailedActivity("At least one target is down")
 
     else:
